Authors
================

* Matthew Westcott (Torchbox) twitter: @gasmanic
* David Cranwell (Torchbox) twitter: @davecranwell
* Karl Hobley (Torchbox) twitter: @kaedroho
* Tim Heap (Takeflight)

Contributors
============

* Helen Chapman helen.chapman@torchbox.com
* Balazs Endresz balazs.endresz@torchbox.com
* Neal Todd neal.todd@torchbox.com
* Paul Hallett (twilio) hello@phalt.co
* Tom Dyson
* Serafeim Papastefanos
* Łukasz Bołdys
* peterarenot
* Levi Gross
* Delgermurun Purevkhuu
* Lewis Cowper
* Stephen Newey
* Ryan Foster
* v1kku
* Miguel Vieira
* Ben Emery
* David Smith
* Ben Margolis
* Tom Talbot
* Jeffrey Hearn
* Robert Clark
* Nathan Brizendine
* thenewguy
* John-Scott Atlakson
* Eric Drechsel
* Alejandro Giacometti
* Robert Rollins
* linibou
* Timo Rieber
* Jerel Unruh
* georgewhewell
* Frank Wiles
* Sebastian Spiegel
* Alejandro Varas
* Martin Sanders
* Benoît Bar
* Claudemiro
* Tiago Henriques
* Arne Schauf
* Jordi Joan
* Damian Moore
* signalkraft
* Mac Chapman
* Brett Grace
* Nar Chhantyal
* Michael Fillier
* Mitchel Cabuloy
* Piet Delport
* Tom Christie
* Michael van Tellingen
* Scot Hacker
* Kyungil Choi
* Joss Ingram
* Christoph Lipp
* Michael Cordover
* Timothy Allen
* Rob Shelton
* Anurag Sharma
* Maximilian Stauss
* Salvador Faria
* Alex Gleason
* Ryan Pineo
* Petr Vacha
* Josh Barr
* Sævar Öfjörð Magnússon
* Ashia Zawaduk
* Denis Voskvitsov
* Kyle Stratis
* Sergey Nikitin


Translators
===========

* Basque: Unai Zalakain
* Bulgarian: Lyuboslav Petrov
* Catalan: David Llop
* Chinese: hanfeng, Lihan Li
* Chinese (China): hanfeng, Jian Li
* Chinese (Taiwan): Lihan Li
* Croatian: Luka Matijević
* Czech: Ivan Pomykacz, Jiri Stepanek
* Dutch: benny_AT_it_digin.com, Bram, Brecht Dervaux, Huib Keemink, Samuel Leeuwenburg, mahulst, Michael van Tellingen, Arne Turpyn
* Dutch (Netherlands): Bram, Franklin Kingma, Maarten Kling
* Finnish: Glen Somerville
* French: Adrien, Timothy Allen, Bertrand Bordage, André Bouatchidzé, Tom Dyson, nahuel
* Galician: fooflare
* Georgian: André Bouatchidzé
* German: Ettore Atalan, Patrick Craston, Florian, Henrik Kröger, Tammo van Lessen, Wasilis Mandratzis-Walz, m0rph3u5, Max Pfeiffer, Karl Sander, Johannes Spielmann
* Greek: Jim Dal, dotoree, Wasilis Mandratzis-Walz, NeotheOne, Serafeim Papastefanos
* Hebrew (Israel): bjesus, Lior Abazon
* Icelandic: Arnar Tumi Þorsteinsson, Sævar Öfjörð Magnússon
* Italian: Claudio Bantaloukas, Giacomo Ghizzani, Alessio Di Stasio, Andrea Tagliazucchi
* Japanese: Sangmin Ahn, Daigo Shitara
* Korean: Kyungil Choi, Ji Han Chung
* Mongolian: Delgermurun Purevkhuu
* Norwegian Bokmål: Eirik Krogstad
* Polish: Mateusz, utek
* Portuguese (Brazil): Claudemiro Alves Feitosa Neto, Gladson Brito, Thiago Cangussu, Gilson Filho, João Luiz Lorencetti, Douglas Miranda
* Portuguese (Portugal): Gladson Brito, Thiago Cangussu, Tiago Henriques, Jose Lourenco, Douglas Miranda
* Romanian: Dan Braghis
* Russian: ajk, Daniil, HNKNTA, Sergey Komarov, Eugene MechanisM
* Spanish: José Alaguna, Mauricio Baeza, Daniel Chimeno, fonso, fooflare, Joaquín Tita, Unai Zalakain
* Swedish: Hannes Lohmander, Ludwig Kjellström
* Turkish (Turkey): José Alaguna
* Ukrainian: Andrey Tykhonov, Mykola Zamkovoi
* Vietnamese: Luan Nguyen
